Bug 1336813 - Use transform for the run-on-projects flag in linux64-jsdcov. r?jmaher draft
authorGreg Mierzwinski <gmierz2@outlook.com>
Sun, 05 Feb 2017 11:35:18 -0500
changeset 479079 ab45f08d2e18522ae5eea2d6831e08ed35d0474c
parent 479078 157ac74dfab5933e6a0dfbdcd2c9b4f160674c93
child 544579 7cabc64bc12c4e11b409c6a07e8ef08b9cf7604c
push id44139
push userbmo:gmierz2@outlook.com
push dateSun, 05 Feb 2017 16:44:15 +0000
reviewersjmaher
bugs1336813
milestone54.0a1
Bug 1336813 - Use transform for the run-on-projects flag in linux64-jsdcov. r?jmaher This patch enables the use of the transform 'enable_code_coverage' to set the 'run-on-projects' for all test suites used by linux64-jsdcov. It also removes the occurences of that flag from the test definition yaml. MozReview-Commit-ID: 66zG9MrFn2i
taskcluster/ci/test/tests.yml
taskcluster/taskgraph/transforms/tests.py
--- a/taskcluster/ci/test/tests.yml
+++ b/taskcluster/ci/test/tests.yml
@@ -421,20 +421,16 @@ mochitest-a11y:
 mochitest-browser-chrome:
     description: "Mochitest browser-chrome run"
     suite:
         by-test-platform:
             linux64-jsdcov/opt: mochitest/browser-chrome-coverage
             default: mochitest/browser-chrome-chunked
     treeherder-symbol: tc-M(bc)
     loopback-video: true
-    run-on-projects:
-        by-test-platform:
-            linux64-jsdcov/opt: []
-            default: ['all']
     chunks:
         by-test-platform:
             linux64-jsdcov/opt: 35
             linux64/debug: 12
             linux32/debug: 12
             linux64-asan/opt: 10
             default: 7
     e10s:
@@ -598,17 +594,16 @@ mochitest-devtools-chrome:
     loopback-video: true
     max-run-time: 5400
     chunks:
         by-test-platform:
             windows.*: 8
             default: 10
     run-on-projects:
         by-test-platform:
-            linux64-jsdcov/opt: []
             windows.*: ['mozilla-central', 'try']
             default: ['all']
     e10s:
         by-test-platform:
             linux64-ccov/opt: false
             linux64-jsdcov/opt: false
             # Bug 1304433: mochitest-devtools-chrome (e10s) not greened on windows
             windows.*: false
@@ -1225,20 +1220,16 @@ web-platform-tests-wdspec:
 
 xpcshell:
     description: "xpcshell test run"
     suite:
         by-test-platform:
             linux64-jsdcov/opt: xpcshell-coverage
             default: xpcshell
     treeherder-symbol: tc-X()
-    run-on-projects:
-        by-test-platform:
-            linux64-jsdcov/opt: []
-            default: ['all']
     chunks:
         by-test-platform:
             linux64/debug: 10
             android-4.2-x86/opt: 6
             # windows.*: 1
             macosx.*: 1
             default: 8
     instance-size:
--- a/taskcluster/taskgraph/transforms/tests.py
+++ b/taskcluster/taskgraph/transforms/tests.py
@@ -483,21 +483,23 @@ def handle_keyed_by(config, tests):
     for test in tests:
         for field in fields:
             resolve_keyed_by(test, field, item_name=test['test-name'])
         yield test
 
 
 @transforms.add
 def enable_code_coverage(config, tests):
     """Enable code coverage for linux64-ccov/opt build-platforms"""
     for test in tests:
         if test['build-platform'] == 'linux64-ccov/opt':
             test['mozharness'].setdefault('extra-options', []).append('--code-coverage')
             test['run-on-projects'] = []
+        elif test['build-platform'] == 'linux64-jsdcov/opt':
+            test['run-on-projects'] = []
         yield test
 
 
@@ -483,21 +483,23 @@ def handle_keyed_by(config, tests):
 @transforms.add
 def enable_code_coverage(config, tests):
-    """Enable code coverage for linux64-ccov/opt build-platforms"""
+    """Enable code coverage for the linux64-ccov/opt & linux64-jsdcov/opt build-platforms"""
     for test in tests:
         if test['build-platform'] == 'linux64-ccov/opt':
 @transforms.add
 def split_e10s(config, tests):
     for test in tests:
         e10s = test['e10s']